summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorspuligil <spuligil@codeaurora.org>2019-12-05 06:00:33 -0800
committerspuligil <spuligil@codeaurora.org>2019-12-05 06:00:34 -0800
commitf82587df5d67ac0449cdc9f8d2a6adb259337ef2 (patch)
tree0b7423af6b5601e86fc1e76a0b99f3303694ad3f
parent952a87e24b3018d27827eda844ec1ecdd35c88dc (diff)
fw-api: CL 8969207 - update fw common interface files
Change-Id: I8e6ea0d969e5d073e008439cb0d024c74c6cbd46 WMI: add tbtt_qtime fields to TBTT offset info CRs-Fixed: 2262693
-rwxr-xr-xfw/wmi_tlv_defs.h4
-rwxr-xr-xfw/wmi_unified.h14
-rwxr-xr-xfw/wmi_version.h2
3 files changed, 16 insertions, 4 deletions
diff --git a/fw/wmi_tlv_defs.h b/fw/wmi_tlv_defs.h
index e0ab1ce9b90d..179a85cd6ad4 100755
--- a/fw/wmi_tlv_defs.h
+++ b/fw/wmi_tlv_defs.h
@@ -4451,7 +4451,9 @@ WMITLV_CREATE_PARAM_STRUC(WMI_MGMT_RX_EVENTID);
/* TBTT offset Event */
#define WMITLV_TABLE_WMI_TBTTOFFSET_UPDATE_EVENTID(id,op,buf,len) \
WMITLV_ELEM(id,op,buf,len, WMITLV_TAG_STRUC_wmi_tbtt_offset_event_fixed_param, wmi_tbtt_offset_event_fixed_param, fixed_param, WMITLV_SIZE_FIX) \
- WMITLV_FXAR(id,op,buf,len, WMITLV_TAG_ARRAY_UINT32, A_UINT32, tbttoffset_list, WMITLV_SIZE_FIX, WMI_MAX_AP_VDEV)
+ WMITLV_FXAR(id,op,buf,len, WMITLV_TAG_ARRAY_UINT32, A_UINT32, tbttoffset_list, WMITLV_SIZE_FIX, WMI_MAX_AP_VDEV) \
+ WMITLV_FXAR(id,op,buf,len, WMITLV_TAG_ARRAY_UINT32, A_UINT32, tbtt_qtime_low_us_list, WMITLV_SIZE_FIX, WMI_MAX_AP_VDEV) \
+ WMITLV_FXAR(id,op,buf,len, WMITLV_TAG_ARRAY_UINT32, A_UINT32, tbtt_qtime_high_us_list, WMITLV_SIZE_FIX, WMI_MAX_AP_VDEV)
WMITLV_CREATE_PARAM_STRUC(WMI_TBTTOFFSET_UPDATE_EVENTID);
/* TBTT EXT offset Event */
diff --git a/fw/wmi_version.h b/fw/wmi_version.h
index f671515e5155..65186b4f577a 100755
--- a/fw/wmi_version.h
+++ b/fw/wmi_version.h
@@ -36,7 +36,7 @@
#define __WMI_VER_MINOR_ 0
/** WMI revision number has to be incremented when there is a
* change that may or may not break compatibility. */
-#define __WMI_REVISION_ 752
+#define __WMI_REVISION_ 753
/** The Version Namespace should not be normally changed. Only
* host and firmware of the same WMI namespace will work
diff --git a/fw/wmi_unified.h b/fw/wmi_unified.h
index 8a59f33a81a0..1fabc8b01f4b 100755
--- a/fw/wmi_unified.h
+++ b/fw/wmi_unified.h
@@ -11493,9 +11493,16 @@ typedef struct {
A_UINT32 tlv_header; /* TLV tag and len; tag equals WMITLV_TAG_STRUC_wmi_tbtt_offset_event_fixed_param */
/** bimtap of VDEVs that has tbtt offset updated */
A_UINT32 vdev_map;
/* The TLVs for tbttoffset_list will follow this TLV.
* tbtt offset list in the order of the LSB to MSB in the vdev_map bitmap
* A_UINT32 tbttoffset_list[WMI_MAX_AP_VDEV];
+ * - tbtt qtime_low_us list(Lower 32 bit of qtime us) in the order of the
+ * LSb to MSb in the vdev_map bitmap
+ * A_UINT32 tbtt_qtime_low_us_list[WMI_MAX_AP_VDEV];
+ * - tbtt qtime_high_us list(Higher 32 bit of qtime us) in the order of the
+ * LSb to MSb in the vdev_map bitmap
+ * A_UINT32 tbtt_qtime_high_us_list[WMI_MAX_AP_VDEV];
*/
} wmi_tbtt_offset_event_fixed_param;
@@ -11505,6 +11512,9 @@ typedef struct {
A_UINT32 vdev_id;
/** tbttoffset in TUs */
A_UINT32 tbttoffset;
+ /** absolute tbtt time in qtime us */
+ A_UINT32 tbtt_qtime_low_us; /* bits 31:0 of qtime */
+ A_UINT32 tbtt_qtime_high_us; /* bits 63:32 of qtime */
} wmi_tbtt_offset_info;
/** Use this event if number of vdevs > 32 */
@@ -11493,9 +11493,16 @@ typedef struct {
/** bimtap of VDEVs that has tbtt offset updated */
A_UINT32 vdev_map;
-/* The TLVs for tbttoffset_list will follow this TLV.
- * tbtt offset list in the order of the LSB to MSB in the vdev_map bitmap
+/* The TLVs for tbttoffset_list, tbtt_qtime_low_us_list, and
+ * tbtt_qtime_high_us_list will follow this TLV.
+ * - tbtt offset list in the order of the LSb to MSb in the vdev_map bitmap
* A_UINT32 tbttoffset_list[WMI_MAX_AP_VDEV];